## 1.0.2.20250711 (2025-07-11)

[jmespath] Remove from pyrightconfig (#14378)

## 1.0.2.20250529 (2025-05-29)

Improve `jmespath` (#14176)

## 1.0.2.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 1.0.2.7 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 1.0.2.6 (2023-03-27)

Add defaults for third-party stubs I-L (#9955)

## 1.0.2.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.0.2.4 (2023-01-05)

Improve various `jmespath` types

Merge `jmespath` from microsoft/python-type-stubs

## 1.0.2.3 (2022-12-21)

Fix return type of `search` in jmespath stubs (#9394)

## 1.0.2.2 (2022-12-14)

Add types for jmespath internals (#9338)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 1.0.2.1 (2022-11-08)

Fix and allow classes with missing metaclasses (#9136)

## 1.0.2 (2022-07-19)

Add missing third party modules (#8321)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: hauntsaninja <>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 1.0.1 (2022-07-07)

Annotate `jmespath` public API (#8253)

## 1.0.0 (2022-06-26)

[stubsabot] Bump jmespath to 1.0.* (#8183)

Co-authored-by: hauntsaninja <>

## 0.10.3 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 0.10.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

